Crate credibil_infosec

Crate credibil_infosec 

Data Security for Credibil

This crate provides common utilities for the Credibil project and is not intended to be used directly.

Re-exports

pub use crate::jose::jwa::Algorithm;
pub use crate::jose::jwe::PublicKey;
pub use crate::jose::jwe::SecretKey;
pub use crate::jose::jwe::SharedSecret;
pub use crate::jose::jwk::PublicKeyJwk;
pub use crate::jose::jws::Jws;
pub use crate::jose::jwt::Jwt;

Modules

cose
COSE
jose
JSON Object Signing and Encryption (JOSE) Proofs
proof
Data Integrity Proofs

Enums

Curve
Cryptographic curve type.
KeyType
Cryptographic key type.

Traits

Receiver
A Receiver (Recipient) is required to decrypt an encrypted message.
Signer
Signer is used by implementers to provide signing functionality for Verifiable Credential issuance and Verifiable Presentation submissions.